/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"type\":\"object\",\"d"
    "escription\":\"Angular notch filter parameters for window glass "
    "echoes\",\"title\":\"Angular Notch Filter\",\"properties\":{\"amplitude_mean\":"
    "{\"type\":\"array\",\"description\":\"Mean amplitude [dB]\",\"items\":{\"type\":\"n"
    "umber\"}},\"range_mean\":{\"type\":\"array\",\"description\":\"Mean range [m]\",\""
    "items\":{\"type\":\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"Angle"
    " [deg]\",\"items\":{\"type\":\"number\"}}},\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0"
    ".094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"am"
    "sl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"type\":\"object\",\"desc"
    "ription\":\"Atmospheric parameters\",\"title\":\"Atmospheric Parameters\",\"pr"
    "operties\":{\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean "
    "sea level (AMSL) "
    "[m]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group velocity "
    "of laser beam "
    "[m/s]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"pressure_sl\":970,\"temperature\":7,\"amsl\":0,\"group_velocity\":299711000"
    ".0,\"pressure\":970,\"wavelength\":1550,\"rel_humidity\":63,\"attenuation\":0."
    "028125}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\"type\":\"object\",\""
    "description\":\"Laser beam geometry details\",\"title\":\"Beam Geometry\",\"pr"
    "operties\":{\"beam_exit_diameter\":{\"type\":\"number\",\"description\":\"Beam "
    "width at exit aperture [m]\",\"minimum\":0,\"exclusiveMinimum\":false},\"bea"
    "m_divergence\":{\"type\":\"number\",\"description\":\"Beam divergence in far "
    "field [rad]\",\"minimum\":0,\"exclusiveMinimum\":false}},\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"types\"],\"type\":\"object\",\"definitions\":{\"checkerboard2x2\""
    ":{\"type\":\"object\",\"description\":\"checkerboard 2 by 2\",\"allOf\":[{\"$ref\""
    ":\"#/definitions/common\"},{\"required\":[\"shape\",\"square_length\"],\"type\":"
    "\"object\",\"description\":\"checkerboard specific properties\",\"properties\""
    ":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\"c"
    "heckerboard2x2\"]},\"square_length\":{\"type\":\"number\",\"description\":\"leng"
    "th of a square of the checkerboard in meters\",\"minimum\":0,\"exclusiveMi"
    "nimum\":true}}}]},\"sphere\":{\"type\":\"object\",\"description\":\"sphere\",\"all"
    "Of\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter\"],"
    "\"type\":\"object\",\"description\":\"sphere specific properties\",\"properties"
    "\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\""
    "sphere\"]},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in meter"
    "s\",\"minimum\":0,\"exclusiveMinimum\":true}}}]},\"rectangle\":{\"type\":\"objec"
    "t\",\"description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},"
    "{\"required\":[\"shape\",\"length\",\"width\"],\"type\":\"object\",\"description\":\""
    "rectangle specific properties\",\"properties\":{\"length\":{\"type\":\"number\""
    ",\"description\":\"length in meters\",\"minimum\":0,\"exclusiveMinimum\":true}"
    ",\"width\":{\"type\":\"number\",\"description\":\"width in meters\",\"minimum\":0,"
    "\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]"
    "}}}]},\"chevron\":{\"type\":\"object\",\"description\":\"chevron\",\"allOf\":[{\"$r"
    "ef\":\"#/definitions/common\"},{\"required\":[\"shape\",\"outside_edge_length\""
    ",\"thickness\"],\"type\":\"object\",\"description\":\"chevron specific properti"
    "es\",\"properties\":{\"outside_edge_length\":{\"type\":\"number\",\"description\""
    ":\"length of the two outer edges in meters\",\"minimum\":0,\"exclusiveMinim"
    "um\":true},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"e"
    "num\":[\"chevron\"]},\"thickness\":{\"type\":\"number\",\"description\":\"thicknes"
    "s in meters\",\"minimum\":0,\"exclusiveMinimum\":true}}}]},\"cylinder\":{\"typ"
    "e\":\"object\",\"description\":\"cylinder\",\"allOf\":[{\"$ref\":\"#/definitions/c"
    "ommon\"},{\"required\":[\"shape\",\"diameter\",\"height\"],\"type\":\"object\",\"des"
    "cription\":\"cylinder specific properties\",\"properties\":{\"shape\":{\"type\""
    ":\"string\",\"description\":\"shape identifier\",\"enum\":[\"cylinder\"]},\"diame"
    "ter\":{\"type\":\"number\",\"description\":\"diameter in meters\",\"minimum\":0,\""
    "exclusiveMinimum\":true},\"height\":{\"type\":\"number\",\"description\":\"heigh"
    "t in meters\",\"minimum\":0,\"exclusiveMinimum\":true}}}]},\"round_corner_cu"
    "be_prism\":{\"type\":\"object\",\"description\":\"round corner cube prism\",\"al"
    "lOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter\"]"
    ",\"type\":\"object\",\"description\":\"round corner cube prism specific prope"
    "rties\",\"properties\":{\"offset\":{\"type\":\"number\",\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\"},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\""
    ",\"enum\":[\"round_corner_cube_prism\"]},\"diameter\":{\"type\":\"number\",\"desc"
    "ription\":\"diameter in meters\",\"minimum\":0,\"exclusiveMinimum\":true}}}]}"
    ",\"circular_disk\":{\"type\":\"object\",\"description\":\"circular disk\",\"allOf"
    "\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter\"],\"t"
    "ype\":\"object\",\"description\":\"circular disk specific properties\",\"prope"
    "rties\":{\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, "
    "e.g. reflector constant "
    "(optional)\"},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\""
    ",\"enum\":[\"circular_disk\"]},\"diameter\":{\"type\":\"number\",\"description\":\""
    "diameter in meters\",\"minimum\":0,\"exclusiveMinimum\":true}}}]},\"common\":"
    "{\"required\":[\"name\",\"shape\"],\"type\":\"object\",\"description\":\"common "
    "object properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"description"
    "\":\"shape identifier\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\""
    "circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"]},\"descri"
    "ption\":{\"type\":\"string\",\"description\":\"string describing the "
    "object\"},\"surface_type\":{\"type\":\"string\",\"description\":\"surface "
    "material type\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"]},\"name\":{\"mi"
    "nLength\":3,\"type\":\"string\",\"description\":\"unique type "
    "identifier\"}}}},\"title\":\"Control Object Catalog\",\"properties\":{\"types\""
    ":{\"type\":\"array\",\"uniqueItems\":true,\"items\":{\"type\":\"object\",\"oneOf\":["
    "{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/definitions/checkerboard"
    "2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\"#/definitions/circular"
    "_disk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref\":\"#/definitions/spher"
    "e\"},{\"$ref\":\"#/definitions/round_corner_cube_prism\"}]}}},\"description\""
    ":\"List of control object type "
    "definitions\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"types\":[{\"length\":0.6,\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(60cm x 30cm)\",\"width\":0.3,\"name\":\"Rectangle "
    "60x30\"},{\"length\":0.8,\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(80cm x 40cm)\",\"width\":0.4,\"name\":\"Rectangle "
    "80x40\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square"
    " length: 30cm)\",\"square_length\":0.3,\"name\":\"Checkerboard2x2 "
    "30\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 50cm)\",\"square_length\":0.5,\"name\":\"Checkerboard2x2 50\"},{\"outs"
    "ide_edge_length\":0.6096,\"shape\":\"chevron\",\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"thickness\":0.1016,\"name\":\"Chevron "
    "24''/4''\"},{\"shape\":\"circular_disk\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\",\"diameter\":0.5,\"name\":\"Circular Disk 50\",\"surface_ty"
    "pe\":\"diffuse\"},{\"offset\":0.0,\"diameter\":0.05,\"surface_type\":\"retro_ref"
    "lective_foil\",\"shape\":\"circular_disk\",\"description\":\"flat circular "
    "reflector from retro-reflective foil\",\"name\":\"RIEGL flat reflector 50 "
    "mm\"},{\"offset\":0.0,\"diameter\":0.1,\"surface_type\":\"retro_reflective_foi"
    "l\",\"shape\":\"circular_disk\",\"description\":\"flat circular reflector from"
    " retro-reflective foil\",\"name\":\"RIEGL flat reflector 100 mm\"},{\"offset"
    "\":0.0,\"diameter\":0.15,\"surface_type\":\"retro_reflective_foil\",\"shape\":\""
    "circular_disk\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"name\":\"RIEGL flat reflector 150 "
    "mm\"},{\"description\":\"cylindrical reflector from retro-reflective foil\""
    ",\"diameter\":0.05,\"height\":0.05,\"surface_type\":\"retro_reflective_foil\","
    "\"shape\":\"cylinder\",\"name\":\"RIEGL cylindrical reflector 50 "
    "mm\"},{\"description\":\"cylindrical reflector from retro-reflective foil\""
    ",\"diameter\":0.1,\"height\":0.1,\"surface_type\":\"retro_reflective_foil\",\"s"
    "hape\":\"cylinder\",\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\"},{\"shape\":\"sphere\",\"description\":\"Sphere (diameter: 200 "
    "mm)\",\"diameter\":0.2,\"name\":\"Sphere 200 mm\"},{\"offset\":0.0,\"shape\":\"rou"
    "nd_corner_cube_prism\",\"description\":\"round corner cube "
    "prism\",\"diameter\":0.05,\"name\":\"Corner Cube Prism 50 "
    "mm\"}],\"comments\":[\"This file contains a list of control object types "
    "(aka. 'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Control Object Reference "
    "file\",\"description\":\"Details about the control object reference file\","
    "\"properties\":{\"reference_file\":{\"required\":[\"file_uuid\",\"file_path\"],\""
    "type\":\"object\",\"description\":\"Reference to a control object file\",\"pro"
    "perties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"detection_probability\"],\"type\":\"object\",\"des"
    "cription\":\"Detection probability as a function of "
    "amplitude\",\"title\":\"Detection Probability\",\"properties\":{\"amplitude\":{"
    "\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\""
    "}},\"detection_probability\":{\"type\":\"array\",\"description\":\"Detection "
    "probability [0..1]\",\"items\":{\"type\":\"number\"}}},\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"device_type\",\"serial_number\"],\"type\":\"object\",\"descripti"
    "on\":\"Details about the device used to acquire the point "
    "cloud\",\"title\":\"Device Information\",\"properties\":{\"device_name\":{\"type"
    "\":\"string\",\"description\":\"Optional device name (e.g. 'Scanner 1' for "
    "multi-scanner "
    "systems)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0,"
    "\"exclusiveMinimum\":false},\"device_build\":{\"type\":\"string\",\"description"
    "\":\"Device build "
    "variant\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"channel_text\":\"\",\"device_type\":\"VZ-400i\",\""
    "channel_number\":0,\"device_build\":\"\",\"serial_number\":\"S2221234\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"type\":\"object\",\"description\":\"Scanner device "
    "geometry details\",\"title\":\"Device Geometry\",\"properties\":{\"primary\":{\""
    "required\":[\"ID\",\"content\"],\"type\":\"object\",\"description\":\"Primary "
    "device geometry structure (mandatory)\",\"properties\":{\"ID\":{\"maxItems\":"
    "2,\"type\":\"array\",\"description\":\"Structure identifier\",\"minItems\":2,\"it"
    "ems\":{\"type\":\"integer\"}},\"content\":{\"type\":\"array\",\"description\":\"Inte"
    "rnal calibration values\",\"items\":{\"type\":\"number\"}}}},\"secondary\":{\"re"
    "quired\":[\"ID\",\"content\"],\"type\":\"object\",\"description\":\"Additional "
    "device geometry structure (optional)\",\"properties\":{\"ID\":{\"maxItems\":2"
    ",\"type\":\"array\",\"description\":\"Structure identifier\",\"minItems\":2,\"ite"
    "ms\":{\"type\":\"integer\"}},\"content\":{\"type\":\"array\",\"description\":\"Inter"
    "nal calibration values\",\"items\":{\"type\":\"number\"}}}},\"amu\":{\"type\":\"ob"
    "ject\",\"description\":\"Angle Measurement "
    "Unit\",\"properties\":{\"frameCC\":{\"type\":\"number\",\"description\":\"Frame "
    "Circle Count (number of LSBs per full rotation about frame axis)\",\"min"
    "imum\":0,\"exclusiveMinimum\":false},\"lineCC\":{\"type\":\"number\",\"descripti"
    "on\":\"Line Circle Count (number of LSBs per full rotation about line ax"
    "is)\",\"minimum\":0,\"exclusiveMinimum\":false}}}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[4,0],\"content\":[0]},\"secondary\":{\"ID\":[91,0],\"conten"
    "t\":[0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"type\":\"object\",\"description\":\"Scanner passive"
    " channel device geometry details\",\"title\":\"Device Geometry Passive Cha"
    "nnel\",\"properties\":{\"primary\":{\"required\":[\"ID\",\"content\"],\"type\":\"obj"
    "ect\",\"description\":\"Primary device geometry structure (mandatory)\",\"pr"
    "operties\":{\"ID\":{\"maxItems\":2,\"type\":\"array\",\"description\":\"Structure "
    "identifier\",\"minItems\":2,\"items\":{\"type\":\"integer\"}},\"content\":{\"type\""
    ":\"array\",\"description\":\"Internal calibration values\",\"items\":{\"type\":\""
    "number\"}}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Output Limits\",\"description\":\"Limits "
    "of the measured values output by the device. The limits depend on the "
    "device type, measurement program and/or scan pattern.\",\"properties\":{\""
    "amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible "
    "amplitude in dB.\"},\"background_radiation_maximum\":{\"type\":\"number\",\"de"
    "scription\":\"Maximum possible background radiation.\"},\"amplitude_minimu"
    "m\":{\"type\":\"number\",\"description\":\"Minimum possible amplitude in "
    "dB.\"},\"mta_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " number of MTA zones.\"},\"background_radiation_minimum\":{\"type\":\"number"
    "\",\"description\":\"Minimum possible background "
    "radiation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in meters.\"},\"reflectance_maximum\":{\"type\":\"number\",\"de"
    "scription\":\"Maximum possible reflectance in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"},\"reflectance_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible"
    " range in "
    "meters.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"deviation_minimum\":{\"type\":\"number\""
    ",\"description\":\"Minimum possible pulse shape "
    "deviation.\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":100.0,\"background_radiation_maximum\":0,\"amplitude"
    "_minimum\":0.0,\"mta_zone_count_maximum\":7,\"background_radiation_minimum"
    "\":0,\"deviation_maximum\":32767,\"reflectance_maximum\":100.0,\"range_maxim"
    "um\":10000.0,\"range_minimum\":2.9,\"reflectance_minimum\":-100.0,\"deviatio"
    "n_minimum\":-1}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"title\":\"Devices Information\",\"description\":\"Details "
    "about the devices used to acquire the point cloud (e.g. when merging "
    "point clouds of different devices)\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"items\":{\"required\":[\"device_type\",\"serial_number\"],"
    "\"type\":\"object\",\"properties\":{\"device_name\":{\"type\":\"string\",\"descript"
    "ion\":\"Optional device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0,"
    "\"exclusiveMinimum\":false},\"device_build\":{\"type\":\"string\",\"description"
    "\":\"Device build "
    "variant\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set"
    " when the original 'riegl.device' entry in the source file was "
    "correctly signed.\"}}}}"
    ,
    /* example: */
    "[{\"device_name\":\"Scanner 1\",\"channel_text\":\"\",\"device_type\":\"VZ-400i\","
    "\"channel_number\":0,\"device_build\":\"\",\"serial_number\":\"S2221234\",\"signe"
    "d\":false},{\"device_name\":\"Scanner 2\",\"channel_text\":\"\",\"device_type\":\""
    "VQ-1560i-DW\",\"channel_number\":1,\"device_build\":\"\",\"serial_number\":\"S22"
    "22680\",\"signed\":true},{\"device_name\":\"Scanner 3\",\"channel_text\":\"\",\"de"
    "vice_type\":\"VQ-1560i-DW\",\"channel_number\":2,\"device_build\":\"\",\"serial_"
    "number\":\"S2222680\",\"signed\":true}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Dyntrig\",\"description\":\"Dyntrig\",\"properties\":{\"tab\":{\"maxIt"
    "ems\":128,\"type\":\"array\",\"description\":\"...\",\"minItems\":1,\"items\":{\"req"
    "uired\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"type\":\"object\",\""
    "description\":\"...\",\"properties\":{\"dec1\":{\"type\":\"number\",\"description\""
    ":\"Decay of post-trigger threshold after del1 in units of "
    "dB/m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of "
    "constant pre-trigger threshold elevation in units of "
    "m\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger threshold in "
    "units of dB\"}}}},\"offset\":{\"type\":\"number\",\"description\":\"Offset in "
    "units of dB, for calculation of "
    "line\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB, "
    "for calculation of line: line number N=(amplitude-offset)/scale\"},\"pre"
    "\":{\"required\":[\"nc\",\"a\"],\"type\":\"object\",\"description\":\"Dyntrig pre "
    "values\",\"properties\":{\"nc\":{\"type\":\"integer\",\"description\":\"Number of "
    "entries\",\"minimum\":0,\"maximum\":255},\"a\":{\"maxItems\":2080,\"type\":\"array"
    "\",\"description\":\"...\",\"minItems\":1,\"items\":{\"type\":\"number\"}}}},\"post\""
    ":{\"required\":[\"nc\",\"a\"],\"type\":\"object\",\"description\":\"Dyntrig post "
    "values\",\"properties\":{\"nc\":{\"type\":\"integer\",\"description\":\"Number of "
    "entries\",\"minimum\":0,\"maximum\":255},\"a\":{\"maxItems\":2080,\"type\":\"array"
    "\",\"description\":\"...\",\"minItems\":1,\"items\":{\"type\":\"number\"}}}}},\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"tab\":[{\"dec1\":0.0,\"del1\":0.0,\"dec2\":0.0,\"thra1\":0.0,\"del2\":0.0,\"thra"
    "2\":0.0}],\"offset\":0.0,\"scale\":1.0,\"pre\":{\"nc\":128,\"a\":[78,86,126,134,3"
    "1]},\"post\":{\"nc\":128,\"a\":[78,86,126,134,31]}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"echo_file\"],\"type\":\"object\",\"description\":\"Details about"
    " echo files\",\"title\":\"Echo Information\",\"properties\":{\"echo_file\":{\"re"
    "quired\":[\"file_extension\"],\"type\":\"object\",\"properties\":{\"file_extensi"
    "on\":{\"type\":\"string\",\"description\":\"Echo file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/channel\",\"desc"
    "ription\":\"one field per channel, field name is channel index\"}},\"type\""
    ":\"object\",\"definitions\":{\"channel\":{\"required\":[\"delay\",\"scale\",\"param"
    "eter\"],\"type\":\"object\",\"properties\":{\"delay\":{\"type\":\"number\",\"descrip"
    "tion\":\"delay calibration in "
    "seconds\"},\"a_lin\":{\"type\":\"number\",\"description\":\"relative linear "
    "amplitude range [0..1]\",\"exclusiveMinimum\":false,\"exclusiveMaximum\":fa"
    "lse,\"minimum\":0,\"maximum\":1},\"scale\":{\"type\":\"number\",\"description\":\"a"
    "mplitude calibration\"},\"parameter\":{\"required\":[\"A\",\"B\",\"gamma\",\"omega"
    "\"],\"type\":\"object\",\"description\":\"parameters of the syswave "
    "exponential "
    "sum\",\"properties\":{\"gamma\":{\"type\":\"array\",\"description\":\"decay in 1/s"
    "econd\",\"items\":{\"type\":\"number\"}},\"omega\":{\"type\":\"array\",\"description"
    "\":\"angular frequency in "
    "Hz\",\"items\":{\"type\":\"number\"}},\"A\":{\"type\":\"array\",\"description\":\"real"
    " part of amplitude factor in units of full-scale\",\"items\":{\"type\":\"num"
    "ber\"}},\"B\":{\"type\":\"array\",\"description\":\"imaginary part of amplitude "
    "factor in units of full-scale\",\"items\":{\"type\":\"number\"}}}}}}},\"additi"
    "onalProperties\":false,\"title\":\"Exponential "
    "Decomposition\",\"description\":\"Details for exponential decomposition of"
    " full waveform "
    "data\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"a_lin\":0.27,\"scale\":1.0,\"paramete"
    "r\":{\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"omega\":[3520208"
    "96.0,3647927552.0,-1977987072.0],\"A\":[0.9772450923919678,0.33543351292"
    "61017,-1.312678575515747],\"B\":[-3.9813032150268555,0.08622030913829803"
    ",-0.3152860999107361]}},\"1\":{\"delay\":3.5e-09,\"a_lin\":0.9,\"scale\":1.0,\""
    "parameter\":{\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"omega\":"
    "[352020896.0,3647927552.0,-1977987072.0],\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,"
    "0.0,-0.3]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amp"
    "litude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]"
    ",\"type\":\"object\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"title\":\"Gaussian Decomp"
    "osition\",\"properties\":{\"range_offset_sec_high_power\":{\"type\":\"array\",\""
    "items\":{\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"number\"}},\"range_offset_sec_low_power\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"}},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"}},\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_db\":[],\"range_offset_sec_"
    "low_power\":[],\"amplitude_lsb_high_power\":[],\"amplitude_lsb_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Geo Tag\",\"description\":\"Point cloud "
    "georeferencing information\",\"properties\":{\"pose\":{\"maxItems\":4,\"type\":"
    "\"array\",\"description\":\"Coordinate Transformation Matrix to transform "
    "from File Coordinate System to Global Coordinate Reference System. 4x4"
    " matrix stored as two dimensional array, row major order.\",\"minItems\":"
    "4,\"items\":{\"maxItems\":4,\"type\":\"array\",\"description\":\"rows\",\"minItems\""
    ":4,\"items\":{\"type\":\"number\",\"description\":\"columns\"}}},\"crs\":{\"type\":\""
    "object\",\"description\":\"Global Coordinate Reference System. Please note"
    " that only 3D Cartesian Coordinate Systems are "
    "allowed.\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0},\"name\":{\"type\":\"string\",\"description\":\"Coordinate "
    "reference system "
    "name\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"epsg\":4978,\"name\":\"WGS84 "
    "Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROI"
    "D[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AU"
    "THORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AU"
    "THORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\"
    "\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\"}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"description\":\"Geometric scale factor applied to "
    "point coordinates\",\"minimum\":0,\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"exclusiveMinimum\":true}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Georeferencing "
    "Parameters\",\"description\":\"Parameters used for georeferencing of the "
    "point cloud\",\"properties\":{\"trajectory_file\":{\"required\":[\"file_extens"
    "ion\"],\"type\":\"object\",\"description\":\"Trajectory data used for "
    "georeferencing of the point cloud\",\"properties\":{\"file_extension\":{\"ty"
    "pe\":\"string\",\"description\":\"Trajectory file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"}}},\"body_coordinate_system_t"
    "ype\":{\"type\":\"string\",\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: NED\",\"enum\":[\"NED\",\"ENU"
    "\"]},\"trajectory_offsets\":{\"type\":\"object\",\"description\":\"Correction "
    "offsets applied to the trajectory data\",\"properties\":{\"offset_pitch\":{"
    "\"type\":\"number\",\"description\":\"[deg]\"},\"offset_yaw\":{\"type\":\"number\",\""
    "description\":\"[deg]\"},\"offset_roll\":{\"type\":\"number\",\"description\":\"[d"
    "eg]\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"},\"version\":{\""
    "type\":\"integer\",\"description\":\"Meaning of offset values and how to "
    "apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_height\":{\"type\":\"number\",\"description\":\"[m"
    "]\"},\"offset_north\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_east\""
    ":{\"type\":\"number\",\"description\":\"[m]\"}}},\"socs_to_rocs_matrix\":{\"maxIt"
    "ems\":4,\"type\":\"array\",\"description\":\"Coordinate Transformation Matrix "
    "to transform from Scanner's Own Coordinate System to Record Coordinate"
    " System. 4x4 matrix stored as two dimensional array, row major order.\""
    ",\"minItems\":4,\"items\":{\"maxItems\":4,\"type\":\"array\",\"description\":\"rows"
    "\",\"minItems\":4,\"items\":{\"type\":\"number\",\"description\":\"columns\"}}},\"so"
    "cs_to_body_matrix\":{\"maxItems\":4,\"type\":\"array\",\"description\":\"Coordin"
    "ate Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"minItems\":4,\"items\":{\"maxItems\":4,\"type\":\"a"
    "rray\",\"description\":\"rows\",\"minItems\":4,\"items\":{\"type\":\"number\",\"desc"
    "ription\":\"columns\"}}}},\"$schema\":\"http://json-schema.org/draft-04/sche"
    "ma#\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_extension\":\"pofx\",\"file_uuid\":\"93a03615-66c0"
    "-4bea-8ff8-c577378fe660\"},\"trajectory_offsets\":{\"offset_pitch\":0.01,\"o"
    "ffset_yaw\":-0.45,\"offset_roll\":0.03,\"offset_time\":18.007,\"version\":0,\""
    "offset_height\":-0.2,\"offset_north\":0.07,\"offset_east\":0.15},\"body_coor"
    "dinate_system_type\":\"NED\",\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]]}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"description\":\"One"
    " field per item, field name is item id, field value is item "
    "name\"}},\"type\":\"object\",\"description\":\"Map of item "
    "names\",\"additionalProperties\":false,\"title\":\"Item "
    "Names\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"47\":\"Name of item with id 47\",\"1\":\"Name of item with id 1\",\"2\":\"Name"
    " of item with id 2\",\"-1\":\"Name of item with id -1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"description\":\"Each field"
    " of the object represents a feature and holds a list of license keys, "
    "where the field name is the feature "
    "name.\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"License "
    "key (example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"}}},\"type\":\"object\",\"description\":\"License keys for "
    "software features\",\"additionalProperties\":false,\"title\":\"Software "
    "License Keys\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - "
    "34EF7E7B\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"MTA Settings\",\"description\":\"Parameters for "
    "MTA processing\",\"properties\":{\"modulation_depth\":{\"type\":\"number\",\"des"
    "cription\":\"Depth of pulse position modulation in meter.\",\"minimum\":0},"
    "\"zone_width\":{\"type\":\"number\",\"description\":\"Width of a MTA zone in me"
    "ter.\",\"minimum\":0},\"zone_count\":{\"type\":\"integer\",\"description\":\"Maxim"
    "um number of MTA zones.\",\"minimum\":0,\"maximum\":255}},\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"modulation_depth\":9.368514,\"zone_width\":149.896225,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"type\":\"object\",\"description\":\"Lookup "
    "table for range correction based on raw range\",\"title\":\"Near Range "
    "Correction "
    "Table\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"type\":\"array\",\"description\":\"Correction value [m] to "
    "be added to the raw range\",\"minItems\":1,\"items\":{\"type\":\"number\"}}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"type\":\"obje"
    "ct\",\"description\":\"Standard deviation for range and amplitude as a "
    "function of amplitude\",\"title\":\"Noise Estimates\",\"properties\":{\"amplit"
    "ude_sigma\":{\"type\":\"array\",\"description\":\"Sigma amplitude [dB]\",\"items"
    "\":{\"type\":\"number\"}},\"amplitude\":{\"type\":\"array\",\"description\":\"Amplit"
    "ude [dB]\",\"items\":{\"type\":\"number\"}},\"range_sigma\":{\"type\":\"array\",\"de"
    "scription\":\"Sigma range [m]\",\"items\":{\"type\":\"number\"}}},\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10"
    ".0],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"typ"
    "e\":\"object\",\"description\":\"Notch filter parameters for window glass "
    "echoes\",\"title\":\"Notch Filter\",\"properties\":{\"amplitude_maximum\":{\"typ"
    "e\":\"number\",\"description\":\"Maximum amplitude [dB]\",\"minimum\":0},\"range"
    "_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_minimum\":-0.5,\"range_maximum\":0.2}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"size\"],\"type\":\"object\",\"definitions\":{\"pixel_size\":{\"max"
    "Items\":2,\"type\":\"array\",\"description\":\"Size of "
    "pixels.\",\"minItems\":2,\"items\":{\"type\":\"number\",\"description\":\"Length "
    "of pixel edge [m].\",\"minimum\":0}}},\"title\":\"Pixel Information\",\"proper"
    "ties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"S"
    "ize of pixels in a locally levelled cartesian coordinate system (xy). "
    "This is only used for pixels based on a map projection.\"},\"size\":{\"$re"
    "f\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels in file "
    "coordinate system.\"}},\"description\":\"Details about the pixels "
    "contained in the "
    "file\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"type\":\"ob"
    "ject\",\"definitions\":{\"file_reference\":{\"required\":[\"file_uuid\",\"file_p"
    "ath\"],\"type\":\"object\",\"description\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane "
    "patch file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}}}},\"title\":\"Plane Patch Matchi"
    "ng\",\"properties\":{\"plane_patch_file_one\":{\"$ref\":\"#/definitions/file_r"
    "eference\",\"description\":\"Reference to the plane patch file one\"},\"plan"
    "e_patch_file_two\":{\"$ref\":\"#/definitions/file_reference\",\"description\""
    ":\"Reference to the plane patch file two\"}},\"description\":\"Details "
    "about the plane patch matching "
    "process\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b"
    "4213\",\"file_path\":\"Record009_Line001/191025_121410_Scanner_1.ptch\"},\"p"
    "lane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fbefa"
    "9\",\"file_path\":\"project.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Plane Patch "
    "Statistics\",\"description\":\"Statistics about plane patches found by "
    "plane patch extractor\",\"properties\":{\"total_area\":{\"type\":\"number\",\"de"
    "scription\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_horizontal"
    "_area\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane "
    "[m\\u00b2]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"settings\",\"classes\"],\"type\":\"object\",\"definitions\":{\"met"
    "hod-2\":{\"required\":[\"plane_classification_method\",\"sloping_plane_class"
    "es_minimum_angle\",\"sloping_plane_classes_maximum_angle\"],\"type\":\"objec"
    "t\",\"description\":\"Classification method 2\",\"properties\":{\"plane_classi"
    "fication_method\":{\"type\":\"integer\",\"description\":\"method ID (=2)\",\"min"
    "imum\":2,\"maximum\":2},\"sloping_plane_classes_minimum_angle\":{\"type\":\"nu"
    "mber\",\"description\":\"minimum inclination angle of sloping plane "
    "patches [deg]\",\"minimum\":-360.0,\"maximum\":360.0},\"sloping_plane_classe"
    "s_maximum_angle\":{\"type\":\"number\",\"description\":\"maximum inclination "
    "angle of sloping plane patches [deg]\",\"minimum\":-360.0,\"maximum\":360.0"
    "}}},\"method-1\":{\"required\":[\"plane_classification_method\",\"maximum_inc"
    "lination_angle_horizontal\"],\"type\":\"object\",\"description\":\"Classificat"
    "ion method 1\",\"properties\":{\"plane_classification_method\":{\"type\":\"int"
    "eger\",\"description\":\"method ID (=1)\",\"minimum\":1,\"maximum\":1},\"maximum"
    "_inclination_angle_horizontal\":{\"type\":\"number\",\"description\":\"maximum"
    " inclination angle of horizontal plane patches "
    "[deg]\",\"minimum\":-360.0,\"maximum\":360.0}}}},\"title\":\"Plane Slope Class"
    " Info\",\"properties\":{\"classes\":{\"patternProperties\":{\"^[0-9]+$\":{\"type"
    "\":\"string\",\"description\":\"one field per class, field name is class "
    "number, field value is class "
    "name\"}},\"type\":\"object\",\"description\":\"Class definition table\",\"additi"
    "onalProperties\":false},\"settings\":{\"type\":\"object\",\"description\":\"Clas"
    "sification settings, details see documentation of rdbplanes\",\"oneOf\":["
    "{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2\"}]}}"
    ",\"description\":\"Settings and classes for plane slope "
    "classification\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"classes\":{\"14\":\"horizontal, pointing down\",\"4\":\"sloping, pointing up"
    " and north\",\"12\":\"sloping, pointing down and north\",\"6\":\"vertical, "
    "pointing east\",\"13\":\"sloping, pointing down and west\",\"5\":\"sloping, "
    "pointing up and west\",\"8\":\"vertical, pointing north\",\"11\":\"sloping, "
    "pointing down and south\",\"3\":\"sloping, pointing up and "
    "south\",\"10\":\"sloping, pointing down and east\",\"1\":\"horizontal, "
    "pointing up\",\"2\":\"sloping, pointing up and east\",\"9\":\"vertical, "
    "pointing west\",\"7\":\"vertical, pointing south\"},\"settings\":{\"plane_clas"
    "sification_method\":2,\"sloping_plane_classes_minimum_angle\":10.0,\"slopi"
    "ng_plane_classes_maximum_angle\":70.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"description\":\"Each field"
    " of the object represents a point attribute group and holds a list of "
    "point attributes, where the field name is the group "
    "name.\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\"}}},\"type\":\"object\",\"description\":\"Grouping and sorting of "
    "point attributes for visualization "
    "purposes\",\"additionalProperties\":false,\"title\":\"Point Attribute "
    "Groups\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.thet"
    "a\",\"riegl.phi\"],\"Secondary Attributes\":[\"riegl.mirror_facet\",\"riegl.wa"
    "veform_available\"],\"Time\":[\"riegl.timestamp\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Point Cloud "
    "Information\",\"description\":\"Details about point cloud "
    "files\",\"properties\":{\"project\":{\"type\":\"string\",\"description\":\"Project"
    " name\"},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field "
    "of application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\","
    "\"BLS\",\"ILS\"]},\"comments\":{\"type\":\"string\",\"description\":\"Comments\"}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"project\":\"Campaign 4\",\"field_of_application\":\"ALS\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"orientation\"],\"type\":\"object\",\"description\":\"Estimated "
    "position and orientation information as measured by GNSS, IMU or "
    "inclination sensors\",\"title\":\"Pose Estimation\",\"properties\":{\"position"
    "\":{\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horizonta"
    "l_accuracy\",\"vertical_accuracy\",\"crs\"],\"type\":\"object\",\"description\":\""
    "Position coordinates and position accuracy values as measured by GNSS "
    "in the specified Coordinate Reference System (CRS)\",\"properties\":{\"ver"
    "tical_accuracy\":{\"type\":\"number\",\"description\":\"Vertical accuracy [m]\""
    ",\"minimum\":0,\"exclusiveMinimum\":true},\"crs\":{\"required\":[\"epsg\"],\"type"
    "\":\"object\",\"description\":\"Global Coordinate Reference "
    "System\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\"}}},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coor"
    "dinate 2 as defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate"
    " 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\"},\"ho"
    "rizontal_accuracy\":{\"type\":\"number\",\"description\":\"Horizontal accuracy"
    " [m]\",\"minimum\":0,\"exclusiveMinimum\":true},\"coordinate_3\":{\"type\":\"num"
    "ber\",\"description\":\"Coordinate 3 as defined by axis 3 of the specified"
    " CRS (e.g., Z, Altitude)\"}}},\"orientation\":{\"required\":[\"roll\",\"pitch\""
    ",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"type\":\"object"
    "\",\"description\":\"Orientation values and orientation accuracies, "
    "measured with IMU or inclination sensors.\",\"properties\":{\"pitch_accura"
    "cy\":{\"type\":\"number\",\"description\":\"Pitch angle accuracy [deg]\",\"minim"
    "um\":0,\"exclusiveMinimum\":true},\"roll_accuracy\":{\"type\":\"number\",\"descr"
    "iption\":\"Roll angle accuracy [deg]\",\"minimum\":0,\"exclusiveMinimum\":tru"
    "e},\"pitch\":{\"type\":\"number\",\"description\":\"Pitch angle about scanner "
    "Y-axis [deg]\",\"minimum\":-360,\"maximum\":360},\"yaw_accuracy\":{\"type\":\"nu"
    "mber\",\"description\":\"Yaw angle accuracy [deg]\",\"minimum\":0,\"exclusiveM"
    "inimum\":true},\"roll\":{\"type\":\"number\",\"description\":\"Roll angle about "
    "scanner X-axis [deg]\",\"minimum\":-360,\"maximum\":360},\"yaw\":{\"type\":\"num"
    "ber\",\"description\":\"Yaw angle about scanner Z-axis [deg]\",\"minimum\":-3"
    "60,\"maximum\":360}}},\"barometric_height_amsl\":{\"type\":\"number\",\"descrip"
    "tion\":\"Altitude determined based on the atmospheric pressure according"
    " to the standard atmosphere laws "
    "[m].\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"position\":{\"vertical_accuracy\":1.3314999341964722,\"crs\":{\"epsg\":4979"
    ",\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84"
    "\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\"
    "\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\"
    "\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\""
    "EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AU"
    "THORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"},\"coordinate_2\":15.645033406,\"coordinate_"
    "1\":48.655799473,\"horizontal_accuracy\":0.810699999332428,\"coordinate_3\""
    ":362.7124938964844},\"orientation\":{\"pitch_accuracy\":0.0094337839368757"
    "45,\"roll_accuracy\":0.009433783936875745,\"pitch\":1.509153024827064,\"yaw"
    "_accuracy\":1.0094337839368757,\"roll\":3.14743073066123,\"yaw\":101.872936"
    "30292045},\"barometric_height_amsl\":386.7457796227932}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"typ"
    "e\":\"object\",\"definitions\":{\"vector\":{\"maxItems\":3,\"type\":\"array\",\"minI"
    "tems\":3,\"items\":{\"type\":\"number\",\"description\":\"Index 0=X, 1=Y, 2=Z "
    "component\"}}},\"title\":\"Pose Sensors\",\"properties\":{\"gyroscope\":{\"requi"
    "red\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_no"
    "nlinearity\"],\"type\":\"object\",\"description\":\"Gyroscope "
    "details\",\"properties\":{\"unit\":{\"type\":\"number\",\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in rad/s\",\"minimum\":0,\"exclusiv"
    "eMinimum\":true},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":"
    "\"Sensitive X axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"z_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle ="
    " 0\"},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"descripti"
    "on\":\"Relative nonlinearity, dimensionless\"},\"origin\":{\"$ref\":\"#/defini"
    "tions/vector\",\"description\":\"Sensor origin in SOCS [m] at frame angle "
    "= 0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = 0\"}}},\"magnetic_field_sensor\":{\"req"
    "uired\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_n"
    "onlinearity\"],\"type\":\"object\",\"description\":\"Magnetic Field Sensor "
    "details\",\"properties\":{\"unit\":{\"type\":\"number\",\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in nT\",\"minimum\":0,\"exclusiveMi"
    "nimum\":true},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Se"
    "nsitive X axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"z_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle ="
    " 0\"},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"descripti"
    "on\":\"Relative nonlinearity, dimensionless\"},\"fixed\":{\"$ref\":\"#/definit"
    "ions/vector\",\"description\":\"Distortion of magnetic field caused by "
    "non-rotating scanner part\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"d"
    "escription\":\"Sensitive Y axis of sensor at frame angle = 0\"}}},\"accele"
    "rometer\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"orig"
    "in\",\"relative_nonlinearity\"],\"type\":\"object\",\"description\":\"Accelerome"
    "ter details\",\"properties\":{\"unit\":{\"type\":\"number\",\"description\":\"Unit"
    " of raw data and calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"minimum"
    "\":0,\"exclusiveMinimum\":true},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\""
    "description\":\"Sensitive X axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"z_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle ="
    " 0\"},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"descripti"
    "on\":\"Relative nonlinearity, dimensionless\"},\"origin\":{\"$ref\":\"#/defini"
    "tions/vector\",\"description\":\"Sensor origin in SOCS [m] at frame angle "
    "= 0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = 0\"}}}},\"description\":\"Details on "
    "position and orientation "
    "sensors\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"gyroscope\":{\"unit\":0.00014544410805683583,\"x_axis\":[-121.19555664062"
    "5,0.8219714164733887,0.2313031703233719],\"offset\":[-50.92609786987305,"
    "146.15643310546875,62.4327278137207],\"z_axis\":[0.555869996547699,119.2"
    "2135162353516,0.467585027217865],\"relative_nonlinearity\":[2.8881763114"
    "44113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"origin\":[0.02"
    "6900000870227814,-0.03999999910593033,-0.08950000256299973],\"y_axis\":["
    "-0.440765917301178,-0.7897399663925171,119.5894775390625]},\"magnetic_f"
    "ield_sensor\":{\"unit\":91.74311828613281,\"x_axis\":[-0.011162743903696537"
    ",-2.315962774446234e-05,0.00016818844596855342],\"offset\":[-23812.05273"
    "4375,5606.57666015625,2493.28125],\"z_axis\":[0.00041987866279669106,7.8"
    "76977906562388e-05,0.011407104320824146],\"relative_nonlinearity\":[0.0,"
    "0.0,0.0],\"fixed\":[-1576.010498046875,1596.081787109375,0.0],\"y_axis\":["
    "0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05]},"
    "\"accelerometer\":{\"unit\":6.666666740784422e-05,\"x_axis\":[-15008.1230468"
    "75,56.956390380859375,-60.5175666809082],\"offset\":[-733.3636474609375,"
    "58.969032287597656,1060.2550048828125],\"z_axis\":[1.639882206916809,151"
    "66.744140625,-116.99742889404297],\"relative_nonlinearity\":[0.0,0.0,0.0"
    "],\"origin\":[0.026900000870227814,-0.03999999910593033,-0.0895000025629"
    "9973],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.3701171875"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"type\":\"object\""
    ",\"description\":\"Laser pulse position modulation used for MTA "
    "resolution\",\"title\":\"Pulse Position Modulation\",\"properties\":{\"length\""
    ":{\"type\":\"integer\",\"description\":\"Length of code\",\"minimum\":0,\"maximum"
    "\":255},\"code_phase_mode\":{\"type\":\"integer\",\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\",\"minimum\":0,\"maximum\":255},\"num_mod_ampl\":{\"type\":\"integer\","
    "\"description\":\"Number of different modulation amplitudes (2: binary mo"
    "dulation)\",\"minimum\":0,\"maximum\":255},\"phase_step\":{\"type\":\"integer\",\""
    "description\":\"Step width in phase of modulation code from line to line"
    "\",\"minimum\":0,\"maximum\":255},\"pulse_interval\":{\"type\":\"array\",\"descrip"
    "tion\":\"Explicit table of the pulse position modulation used for MTA "
    "resolution. Table gives times between successive laser pulses in secon"
    "ds.\",\"items\":{\"type\":\"number\",\"minimum\":0}}},\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"length\":31,\"code_phase_mode\":2,\"num_mod_ampl\":2,\"phase_step\":5,\"puls"
    "e_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-"
    "06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.75937"
    "5e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06"
    ",2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06]}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"type\":\"object\","
    "\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"title\":\"Range Statistics\",\"properties\":{\"average\":{\"type\":\"nu"
    "mber\",\"description\":\"Average "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"average\":15.49738,\"minimum\":0.919,\"std_dev\":24.349,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"fp_table_row\":{\"maxItems\":2048,\"type\""
    ":\"array\",\"minItems\":1,\"items\":{\"type\":\"number\"}},\"fp_table\":{\"required"
    "\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"type\":\"object\",\"desription\":\"scanner "
    "internal data\",\"properties\":{\"nx\":{\"type\":\"integer\",\"min\":1,\"descripti"
    "on\":\"number of x entries\",\"max\":2048},\"tc\":{\"type\":\"integer\",\"min\":0,\""
    "description\":\"table data type "
    "code\",\"max\":255},\"ny\":{\"type\":\"integer\",\"min\":1,\"description\":\"number "
    "of y entries\",\"max\":2048},\"ch\":{\"type\":\"integer\",\"min\":0,\"description\""
    ":\"channel number\",\"max\":255},\"tv\":{\"maxItems\":2048,\"type\":\"array\",\"min"
    "Items\":1,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"typ"
    "e\":\"number\"}]}}}},\"fp\":{\"required\":[\"s\",\"w\"],\"type\":\"object\",\"descript"
    "ion\":\"Fingerprint values\",\"properties\":{\"w\":{\"maxItems\":256,\"type\":\"ar"
    "ray\",\"minItems\":1,\"items\":{\"maxItems\":5,\"type\":\"array\",\"minItems\":5,\"i"
    "tems\":{\"type\":\"number\"}}},\"s\":{\"maxItems\":256,\"type\":\"array\",\"minItems"
    "\":1,\"items\":{\"maxItems\":4096,\"type\":\"array\",\"minItems\":1,\"items\":{\"typ"
    "e\":\"number\"}}}}}},\"title\":\"Receiver Internals\",\"properties\":{\"t\":{\"pat"
    "ternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"description\":\""
    "one field per channel, field name is channel index\"}},\"type\":\"object\","
    "\"additionalProperties\":false},\"si\":{\"type\":\"number\",\"description\":\"Sta"
    "rt index (hw_start)\",\"minimum\":0,\"maximum\":255},\"ns\":{\"type\":\"integer\""
    ",\"description\":\"Number of samples\",\"minimum\":0,\"maximum\":4095},\"nt\":{\""
    "type\":\"integer\",\"description\":\"Number of traces\",\"minimum\":0,\"maximum\""
    ":255},\"mw\":{\"type\":\"number\",\"description\":\"Maximum weight\",\"minimum\":0"
    ",\"exclusiveMinimum\":true,\"maximum\":4095},\"tbl\":{\"type\":\"array\",\"descri"
    "ption\":\"various internal data\",\"minItems\":1,\"items\":{\"$ref\":\"#/definit"
    "ions/fp_table\"}},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\"},\"a\":{\"maxItems\":256,\"type\":\"array\",\"description\":\"Amplitude "
    "[dB]\",\"minItems\":1,\"items\":{\"type\":\"number\"}},\"sr\":{\"type\":\"number\",\"d"
    "escription\":\"Sample rate "
    "[Hz]\",\"minimum\":0,\"exclusiveMinimum\":true}},\"description\":\"Receiver "
    "Internals\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"t\":{\"0\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":[[1.23,4.56"
    "],[7.89,0.12]]},\"1\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":["
    "[1.23,4.56],[7.89,0.12]]}},\"si\":48,\"ns\":400,\"nt\":128,\"mw\":31,\"tbl\":[{\""
    "nx\":5,\"tc\":1,\"ny\":2,\"ch\":0,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]]}],"
    "\"a\":[-1.55],\"sr\":7959997000.0}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"type\":\"object\",\"description\":\"Lookup "
    "table for reflectance calculation based on amplitude and "
    "range\",\"title\":\"Reflectance Calculation "
    "Table\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"type\":\"array\",\"description\":\"Correction value [dB] to"
    " be added to the amplitude\",\"minItems\":1,\"items\":{\"type\":\"number\"}}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"]"
    ",\"type\":\"object\",\"description\":\"Range-dependent and "
    "scan-angle-dependent correction of reflectance "
    "reading\",\"title\":\"Near-range reflectance correction\",\"properties\":{\"li"
    "ne_angles_deg\":{\"type\":\"array\",\"description\":\"Angle [deg]\",\"items\":{\"t"
    "ype\":\"number\"}},\"reflectance_correction_db\":{\"type\":\"array\",\"descripti"
    "on\":\"Near range reflectance correction in dB as a function of range "
    "over angle\",\"items\":{\"type\":\"array\",\"description\":\"rows (each array "
    "corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an "
    "angle)\"}}},\"ranges_m\":{\"type\":\"array\",\"description\":\"Range [m]\",\"items"
    "\":{\"type\":\"number\"}}},\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\"}"
    ,
    /* example: */
    "{\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"reflecta"
    "nce_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0"
    ".7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1"
    ",0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"program\":{\"required\":[\"name\"],\"type\":\"object\",\"descri"
    "ption\":\"Measurement program\",\"properties\":{\"laser_prr\":{\"type\":\"number"
    "\",\"description\":\"Laser Pulse Repetition Rate [Hz]\",\"minimum\":0,\"exclus"
    "iveMinimum\":false},\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement program\"}}}},\"title\":\"Scan Pattern\",\"description\":\"Scan "
    "pattern description\",\"properties\":{\"segments\":{\"required\":[\"list\"],\"ty"
    "pe\":\"object\",\"description\":\"Segmented Line Scan Pattern\",\"properties\":"
    "{\"program\":{\"$ref\":\"#/definitions/program\"},\"list\":{\"type\":\"array\",\"it"
    "ems\":{\"required\":[\"start\",\"stop\",\"increment\"],\"type\":\"object\",\"descrip"
    "tion\":\"Line Scan Segment\",\"properties\":{\"increment\":{\"type\":\"number\",\""
    "description\":\"Increment of angle in SOCS [deg]\",\"minimum\":0.0,\"maximum"
    "\":90.0},\"start\":{\"type\":\"number\",\"description\":\"Start angle in SOCS [d"
    "eg]\",\"minimum\":0.0,\"maximum\":360.0},\"stop\":{\"type\":\"number\",\"descripti"
    "on\":\"Stop angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":720.0}}}}}},\"li"
    "ne\":{\"required\":[\"start\",\"stop\",\"increment\"],\"type\":\"object\",\"descript"
    "ion\":\"Line Scan Pattern\",\"properties\":{\"increment\":{\"type\":\"number\",\"d"
    "escription\":\"Increment of angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\""
    ":90.0},\"start\":{\"type\":\"number\",\"description\":\"Start angle in SOCS [de"
    "g]\",\"minimum\":0.0,\"maximum\":360.0},\"program\":{\"$ref\":\"#/definitions/pr"
    "ogram\"},\"stop\":{\"type\":\"number\",\"description\":\"Stop angle in SOCS [deg"
    "]\",\"minimum\":0.0,\"maximum\":720.0}}},\"rectangular\":{\"required\":[\"phi_st"
    "art\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_incr"
    "ement\"],\"type\":\"object\",\"description\":\"Rectangular Field Of View Scan "
    "Pattern\",\"properties\":{\"theta_stop\":{\"type\":\"number\",\"description\":\"St"
    "op theta angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":180.0},\"phi_star"
    "t\":{\"type\":\"number\",\"description\":\"Start phi angle in SOCS [deg]\",\"min"
    "imum\":0.0,\"maximum\":360.0},\"phi_stop\":{\"type\":\"number\",\"description\":\""
    "Stop phi angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":720.0},\"theta_st"
    "art\":{\"type\":\"number\",\"description\":\"Start theta angle in SOCS [deg]\","
    "\"minimum\":0.0,\"maximum\":180.0},\"program\":{\"$ref\":\"#/definitions/progra"
    "m\"},\"theta_increment\":{\"type\":\"number\",\"description\":\"Increment of "
    "theta angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":90.0},\"phi_incremen"
    "t\":{\"type\":\"number\",\"description\":\"Increment of phi angle in SOCS [deg"
    "]\",\"minimum\":0.0,\"maximum\":90.0}}}},\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_stop\":130.0,\"phi_start\":45.0,\"phi_stop\":270.0,\""
    "theta_start\":30.0,\"program\":{\"laser_prr\":100000.0,\"name\":\"High "
    "Speed\"},\"theta_increment\":0.04,\"phi_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Shot Information\",\"description\":\"Details "
    "about laser shot files\",\"properties\":{\"shot_file\":{\"required\":[\"file_e"
    "xtension\"],\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"str"
    "ing\",\"description\":\"Shot file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"activated\",\"filters\"],\"type\":\"object\",\"description\":\"Poi"
    "nt filters applied in addition to the application-defined "
    "filters\",\"title\":\"Stored filters\",\"properties\":{\"activated\":{\"type\":\"b"
    "oolean\",\"description\":\"Apply ('true') or ignore ('false') all "
    "filters\"},\"filters\":{\"type\":\"array\",\"description\":\"List of point filte"
    "rs\",\"items\":{\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\""
    "type\":\"object\",\"description\":\"Point filter "
    "definition\",\"properties\":{\"filter\":{\"type\":\"string\",\"description\":\"The"
    " RDB filter string to apply (e.g. when reading points or index), "
    "details see documentation of function "
    "select()\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter "
    "title (e.g. for display in a selection "
    "list)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or"
    " ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"}}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"title\":\"Ignore uncertain points from MTA "
    "resolution\",\"activated\":false,\"description\":\"Ignore points with "
    "uncertain MTA zone "
    "assignment\"},{\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false,\"description\":\"Ignore points with an echo "
    "signal amplitude below the dynamic "
    "trigger\"},{\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are outside "
    "the outer AABB in BOCS\"},{\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are inside "
    "the inner AABB in BOCS\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"],\"type\":"
    "\"object\",\"description\":\"Details of major system components like lidar "
    "sensors, cameras and navigation devices\",\"title\":\"System Description\","
    "\"properties\":{\"system\":{\"type\":\"object\",\"description\":\"The actual "
    "system description, details see documentation of RIEGL System "
    "Description\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the "
    "document\"},\"version\":{\"type\":\"string\",\"description\":\"Document format "
    "version\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time of"
    " creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"$class\":{\"type\":\"string\""
    ",\"description\":\"Object class name\",\"enum\":[\"Document\"]}},\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"author\":\"RIEGL LMS GmbH, Austria\",\"version\":\"1.2.1\",\"ti"
    "mestamp\":\"2022-09-30T11:56:26+00:00\",\"$class\":\"Document\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"conversion_table\":{\"required\":[\"value"
    "\",\"temperature\"],\"type\":\"object\",\"properties\":{\"temperature\":{\"type\":\""
    "array\",\"description\":\"Temperature [\\u00b0C]\",\"items\":{\"type\":\"number\"}"
    "},\"value\":{\"type\":\"array\",\"description\":\"LSB "
    "[1]\",\"items\":{\"type\":\"number\"}}}}},\"title\":\"Temperature Calculation Ta"
    "ble\",\"properties\":{\"InGaAs\":{\"$ref\":\"#/definitions/conversion_table\",\""
    "description\":\"Conversion table for InGaAs channel\"},\"Si\":{\"$ref\":\"#/de"
    "finitions/conversion_table\",\"description\":\"Conversion table for Si cha"
    "nnel\"},\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitions/conversion_table\""
    ",\"description\":\"Conversion table for InGaAs - Si "
    "difference\"}},\"description\":\"Conversion of background radiation raw "
    "values to temperatures in "
    "\\u00b0C\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478247277,311.118"
    "8086915047,313.10025350480055,315.2137946389828,317.2172555057597,319."
    "2207163725366,321.2021611858325,323.3157023200148],\"value\":[0.0,64.000"
    "97659230323,128.0019531846065,192.0029297769097,256.0039063692129,320."
    "00488296151616,384.0058595538194,448.0068361461226,512.0078127384259]}"
    ",\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"epoch\",\"source\"],\"type\":\"object\",\"description\":\"Base of "
    "timestamps (epoch)\",\"title\":\"Time "
    "Base\",\"properties\":{\"source\":{\"type\":\"string\",\"description\":\"Timestamp"
    " source\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"]},\"epoch\":{\"type\":\"string\",\"de"
    "scription\":\"Date and time of timestamp '0' as proposed by RFC 3339 "
    "(e.g. 2015-10-27T00:00:00+01:00).\"},\"system\":{\"type\":\"string\",\"descrip"
    "tion\":\"Time system (time standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"time_interval\",\"navigation_frame\"],\"type\":\"object\",\"desc"
    "ription\":\"Details about position+orientation "
    "files\",\"title\":\"Trajectory Information\",\"properties\":{\"project\":{\"type"
    "\":\"string\",\"description\":\"Project "
    "name\"},\"navigation_frame\":{\"type\":\"string\",\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: East-North-Up)\",\"enum\":[\"unknown\",\"N"
    "ED\",\"ENU\"]},\"time_interval\":{\"required\":[\"minimum\",\"average\",\"maximum\""
    ",\"std_dev\"],\"type\":\"object\",\"description\":\"Time interval statistics\",\""
    "properties\":{\"average\":{\"type\":\"number\",\"description\":\"Average time "
    "interval [s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time "
    "interval [s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation of intervals "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"}}},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field "
    "of application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\","
    "\"BLS\",\"ILS\"]},\"software\":{\"type\":\"string\",\"description\":\"Software that"
    " calculated the trajectory (this may be the same or different software"
    " than the one that created the "
    "file)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation device, "
    "e.g. "
    "name/type/serial\"},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\"},\"location\":{\"type\":\"string\",\"description\":\"Project location, "
    "e.g. city/state/country\"}},\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\"}"
    ,
    /* example: */
    "{\"project\":\"Campaign 3\",\"navigation_frame\":\"NED\",\"time_interval\":{\"ave"
    "rage\":0.00500053,\"minimum\":0.00500032,\"std_dev\":5.51e-07,\"maximum\":0.0"
    "05004883},\"field_of_application\":\"MLS\",\"software\":\"Navigation Software"
    " XYZ\",\"device\":\"IMU Model 12/1, Serial# 12345\",\"company\":\"RIEGL "
    "LMS\",\"settings\":\"default\",\"location\":\"Horn\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\""
    "ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"d"
    "mi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr"
    "\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_inte"
    "rval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in"
    "_max_duration\",\"in_max_delay\"],\"type\":\"object\",\"description\":\"Trigger-"
    "Timestamping-Unit/IP configuration\",\"title\":\"TTIP Configuration\",\"prop"
    "erties\":{\"ext_delay\":{\"type\":\"integer\",\"description\":\"external "
    "trigger, time delay [0.1 msec]\",\"minimum\":0},\"input_descr\":{\"type\":\"st"
    "ring\",\"description\":\"descriptive "
    "string\"},\"output_usage\":{\"type\":\"integer\",\"description\":\"0 .. no "
    "output, 1 .. output derived from internal clock, 2 .. output derived "
    "from dmi, 3 .. output derived from external signal, 4 .. output static"
    " low, 5 .. output static "
    "high\",\"minimum\":0},\"channel\":{\"type\":\"integer\",\"description\":\"ID of "
    "input/output channel\",\"minimum\":0},\"output_descr\":{\"type\":\"string\",\"de"
    "scription\":\"descriptive "
    "string\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\"},\"input_usage\":{\"type\":\"integer\",\"description\":\"0 .. deactivated,"
    " 1 .. just detecting and timestamping\",\"minimum\":0},\"ext_subdivider\":{"
    "\"type\":\"integer\",\"description\":\"reduces the frequency, default "
    "1\",\"minimum\":0},\"in_polarity\":{\"type\":\"integer\",\"description\":\"0 .. "
    "positive edge, 1 .. negative "
    "edge\",\"minimum\":0},\"out_delay\":{\"type\":\"integer\",\"description\":\"output"
    " pulse initial delay after start [0.1 msec]\",\"minimum\":0},\"num_channel"
    "\":{\"type\":\"integer\",\"description\":\"number of input/output channels\",\"m"
    "inimum\":0},\"ttip_version\":{\"type\":\"integer\",\"description\":\"following m"
    "ain.sub.ss.sss\",\"minimum\":0},\"in_max_delay\":{\"type\":\"integer\",\"descrip"
    "tion\":\"maximum delay to output pulse before fake event is generated "
    "[0.1 msec], zero indicates that no fake events are generated\",\"minimum"
    "\":0},\"out_duration\":{\"type\":\"integer\",\"description\":\"output pulse "
    "duration [0.1 msec]\",\"minimum\":0},\"dmi_max_time\":{\"type\":\"integer\",\"de"
    "scription\":\"dmi, maximum time interval between trigger events [0.1 mse"
    "c]\",\"minimum\":0},\"dmi_min_time\":{\"type\":\"integer\",\"description\":\"dmi, "
    "minimum time interval between trigger events [0.1 "
    "msec]\",\"minimum\":0},\"ext_channel\":{\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates none\",\"minimum"
    "\":0},\"out_num_pulses\":{\"type\":\"integer\",\"description\":\"number of "
    "output pulses to be generated, 0 .. infinite\",\"minimum\":0},\"in_min_dur"
    "ation\":{\"type\":\"integer\",\"description\":\"input signals with smaller "
    "pulse durations are ignored [0.1 msec]\",\"minimum\":0},\"ext_bitmask\":{\"t"
    "ype\":\"integer\",\"description\":\"defines which of the internal pulse "
    "generators are to be started\",\"minimum\":0},\"out_polarity\":{\"type\":\"int"
    "eger\",\"description\":\"0 .. positive edge, 1 .. negative "
    "edge\",\"minimum\":0},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, "
    "increment in "
    "ticks\"},\"out_interval\":{\"type\":\"integer\",\"description\":\"output pulse "
    "interval [0.1 "
    "msec]\",\"minimum\":0},\"ext_signal\":{\"type\":\"integer\",\"description\":\"0 .."
    " use input signal, 1 .. use output signal of channel\",\"minimum\":0},\"in"
    "_max_duration\":{\"type\":\"integer\",\"description\":\"stops measurement of "
    "pulse duration of input signal [0.1 msec]\",\"minimum\":0}},\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"ext_delay\":0,\"input_descr\":\"Port 1 - "
    "Exposure\",\"output_usage\":1,\"channel\":0,\"output_descr\":\"Port 1 - Trigge"
    "r\",\"dmi_dist_per_tick\":0.0,\"input_usage\":1,\"ext_subdivider\":1,\"in_pola"
    "rity\":0,\"out_delay\":0,\"num_channel\":9,\"ttip_version\":1,\"in_max_delay\":"
    "9990,\"out_duration\":300,\"dmi_max_time\":0,\"dmi_min_time\":0,\"ext_channel"
    "\":32,\"out_num_pulses\":1,\"in_min_duration\":0,\"ext_bitmask\":0,\"out_polar"
    "ity\":0,\"dmi_incr\":0,\"out_interval\":10000,\"ext_signal\":0,\"in_max_durati"
    "on\":10000}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Vertex Information\",\"description\":\"Details "
    "about vertex file\",\"properties\":{\"vertex_file\":{\"required\":[\"file_exte"
    "nsion\"],\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"string"
    "\",\"description\":\"Vertex file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about the voxels contained in "
    "the file\",\"oneOf\":[{\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"p"
    "roperties\":{\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds"
    "\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size\":{\"descripti"
    "on\":\"Size of voxels in file coordinate system.\",\"oneOf\":[{\"$ref\":\"#/de"
    "finitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}]},\"vo"
    "xel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"}},\"additionalPro"
    "perties\":false},{\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"vox"
    "el_origin\",\"voxel_type\"],\"properties\":{\"size_llcs\":{\"$ref\":\"#/definiti"
    "ons/voxel_size\",\"description\":\"Size of voxels in a locally levelled "
    "cartesian coordinate system (xyz). This is only used for voxels based "
    "on a map projection.\"},\"reference_point\":{\"maxItems\":2,\"type\":\"array\","
    "\"description\":\"Point in WGS84 geodetic decimal degree (EPSG:4326) that"
    " was used to compute the projection distortion parameters. The "
    "coefficient order is latitude, longitude. Only voxels with "
    "corresponding geo_tag, voxel_size and reference_point can be reliably "
    "processed together. This entry is available for voxel files in "
    "projected CRS only.\",\"minItems\":2,\"items\":{\"type\":\"number\",\"minimum\":-"
    "180,\"maximum\":180}},\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"descrip"
    "tion\":\"Size of voxels in file coordinate system.\"},\"voxel_type\":{\"$ref"
    "\":\"#/definitions/voxel_type\"},\"shape_thresholds\":{\"$ref\":\"#/definition"
    "s/shape_thresholds\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/definitions/v"
    "oxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_point\",\"descrip"
    "tion\":\"The base point of the voxel grid. Used together with "
    "<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c"
    "oordinates.\"}]}},\"additionalProperties\":false}],\"definitions\":{\"voxel_"
    "size\":{\"maxItems\":3,\"type\":\"array\",\"description\":\"Size of voxels.\",\"mi"
    "nItems\":3,\"items\":{\"$ref\":\"#/definitions/edge_length\"}},\"voxel_origin_"
    "enum\":{\"default\":\"corner\",\"description\":\"Defines whether the voxel's "
    "center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\",\"enum\":["
    "\"center\",\"corner\"]},\"voxel_size_cubic\":{\"$ref\":\"#/definitions/edge_len"
    "gth\",\"type\":\"number\"},\"voxel_origin_point\":{\"maxItems\":3,\"type\":\"array"
    "\",\"description\":\"Origin point for all voxel indices in voxel CRS.\",\"mi"
    "nItems\":3,\"items\":{\"type\":\"number\"}},\"edge_length\":{\"type\":\"number\",\"d"
    "escription\":\"Length of voxel edge [m].\",\"minimum\":0,\"exclusiveMinimum\""
    ":true},\"shape_thresholds\":{\"required\":[\"plane\",\"line\"],\"type\":\"object\""
    ",\"description\":\"Thresholds used to compute the voxel's shape_id "
    "value.\",\"properties\":{\"plane\":{\"type\":\"number\",\"description\":\"If the "
    "smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"exclusiveMinimum\":"
    "true,\"exclusiveMaximum\":true,\"minimum\":0,\"maximum\":1},\"line\":{\"type\":\""
    "number\",\"description\":\"If the biggest eigenvalue is bigger than the "
    "median eigenvalue * line_threshold, the voxel is considered a line.\",\""
    "minimum\":1,\"exclusiveMinimum\":true}}},\"voxel_type\":{\"default\":\"centroi"
    "d\",\"description\":\"Whether a point in a voxel represents its center or "
    "its centroid. If type is <tt>index</tt> there is no point but only an "
    "integer voxel "
    "index.\",\"enum\":[\"center\",\"centroid\",\"index\"]}},\"title\":\"Voxel "
    "Information\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303,0.5143705304787237"
    "],\"reference_point\":[48,16],\"shape_thresholds\":{\"plane\":0.16,\"line\":6}"
    ",\"voxel_type\":\"centroid\",\"size\":[0.5971642834779395,0.5971642834779395"
    ",0.5143705304787237],\"voxel_origin\":\"corner\"}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"num_shots\",\"mta_zone\"],\"type\":\"object\",\"description\":\"Se"
    "ttings for waveform averaging\",\"title\":\"Waveform Averaging Settings\",\""
    "properties\":{\"num_shots\":{\"type\":\"integer\",\"description\":\"Number of "
    "consecutive shots to be used for averaging.\",\"minimum\":1},\"trim\":{\"typ"
    "e\":\"number\",\"default\":0,\"description\":\"Percentage for robust averaging"
    ".\",\"minimum\":0,\"maximum\":0.5},\"mta_zone\":{\"type\":\"integer\",\"descriptio"
    "n\":\"Fixed MTA zone for averaging.\",\"minimum\":1}},\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"num_shots\":7,\"trim\":0.05,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"sample_block_file\",\"sample_data_files\"],\"type\":\"object\","
    "\"description\":\"Details about waveform files\",\"title\":\"Waveform Informa"
    "tion\",\"properties\":{\"sample_block_file\":{\"required\":[\"file_extension\"]"
    ",\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"string\",\"desc"
    "ription\":\"Sample block file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}}},\"sample_data_files\":{\"type\":\"array\",\""
    "items\":{\"required\":[\"channel\",\"channel_name\",\"sample_interval\",\"sample"
    "_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"],\"type\":\"object\""
    ",\"properties\":{\"file_extension\":{\"type\":\"string\",\"description\":\"Sample"
    " data file extension, without the leading dot\"},\"delta_st\":{\"type\":\"nu"
    "mber\",\"description\":\"reserved\"},\"file_uuid\":{\"type\":\"string\",\"descript"
    "ion\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"sample_bits\":{\"type\":\"integer\",\"description\":\"Bitwidth"
    " of samples (e.g. 10 bit, 12 bit)\",\"exclusiveMinimum\":false,\"exclusive"
    "Maximum\":false,\"minimum\":0,\"maximum\":32},\"laser_wavelength\":{\"type\":\"n"
    "umber\",\"description\":\"Laser wavelength in meters (0 = unknown)\",\"minim"
    "um\":0,\"exclusiveMinimum\":false},\"channel\":{\"type\":\"integer\",\"descripti"
    "on\":\"Sample block channel number (255 = invalid)\",\"exclusiveMinimum\":f"
    "alse,\"exclusiveMaximum\":false,\"minimum\":0,\"maximum\":255},\"sample_inter"
    "val\":{\"type\":\"number\",\"description\":\"Sampling interval in seconds\",\"mi"
    "nimum\":0,\"exclusiveMinimum\":false}}}},\"range_offset_m\":{\"type\":\"number"
    "\",\"description\":\"Calibrated device specific range offset for waveform "
    "analysis by system response fitting in meters.\"},\"range_offset_wavefor"
    "m_samples_m\":{\"type\":\"number\",\"description\":\"Calibrated device "
    "specific range offset for waveform samples in "
    "meters.\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"file_extension\":\"sp0\",\"delta_st\":0,\"file_uuid\""
    ":\"da084413-e3e8-4655-a122-071de8490d8e\",\"channel_name\":\"high_power\",\"s"
    "ample_bits\":12,\"laser_wavelength\":0,\"channel\":0,\"sample_interval\":1.00"
    "503e-09},{\"file_extension\":\"sp1\",\"delta_st\":0,\"file_uuid\":\"93585b5e-5e"
    "a9-43a1-947b-e7ba3be642d2\",\"channel_name\":\"low_power\",\"sample_bits\":12"
    ",\"laser_wavelength\":0,\"channel\":1,\"sample_interval\":1.00503e-09},{\"fil"
    "e_extension\":\"sp5\",\"delta_st\":0,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1"
    "cf8e517f3a0\",\"channel_name\":\"wwf\",\"sample_bits\":12,\"laser_wavelength\":"
    "0,\"channel\":5,\"sample_interval\":1.00503e-09}],\"sample_block_file\":{\"fi"
    "le_extension\":\"sbx\",\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    "},\"range_offset_m\":3.1415,\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"title\":\"Waveform Settings\",\"description\":\"Scanner "
    "settings for waveform output\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"items\":{\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mas"
    "k\"],\"type\":\"object\",\"properties\":{\"channel_idx_mask\":{\"type\":\"integer\""
    ",\"description\":\"Bit mask for channels which belong to sbl_name: "
    "Channel 0 = Bit0, Channel 1 = Bit1, "
    "...\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than "
    "[m]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range less than "
    "[m]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform "
    "output enabled\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"T"
    "hreshold for deviation greater than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than [1]\"}}}}"
    ,
    /* example: */
    "[{\"channel_idx_mask\":11,\"enabled\":true,\"pass_rng_greater\":9.27,\"pass_r"
    "ng_less\":13.11,\"smart_enabled\":true,\"pass_ampl_greater\":1.0,\"pass_ampl"
    "_less\":5.0,\"sbl_name\":\"wfm\"},{\"channel_idx_mask\":32,\"enabled\":false,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"result\",\"filter\",\"settings\"],\"type\":\"object\",\"descriptio"
    "n\":\"Window analysis data estimated from scandata and resulting filter "
    "parameters\",\"title\":\"Window Analysis\",\"properties\":{\"filter\":{\"require"
    "d\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"],\"type\":\"object\",\""
    "properties\":{\"range_max\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{"
    "\"type\":\"number\"}},\"amplitude_max\":{\"type\":\"array\",\"description\":\"[dB]\""
    ",\"items\":{\"type\":\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"[de"
    "g]\",\"items\":{\"type\":\"number\"}},\"range_min\":{\"type\":\"array\",\"descriptio"
    "n\":\"[m]\",\"items\":{\"type\":\"number\"}}}},\"result\":{\"required\":[\"angle\",\"r"
    "ange_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude"
    "_offset\"],\"type\":\"object\",\"properties\":{\"amplitude_offset\":{\"type\":\"ar"
    "ray\",\"description\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"range_mean\":{\"ty"
    "pe\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},\"timestamp\""
    ":{\"type\":\"array\",\"description\":\"[s]\",\"items\":{\"type\":\"number\"}},\"ampli"
    "tude_sigma\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"type\":\"numb"
    "er\"}},\"amplitude_mean\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\""
    "type\":\"number\"}},\"range_sigma\":{\"type\":\"array\",\"description\":\"[m]\",\"it"
    "ems\":{\"type\":\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"[deg]\","
    "\"items\":{\"type\":\"number\"}}}},\"settings\":{\"required\":[\"range\",\"amplitud"
    "e\"],\"type\":\"object\",\"properties\":{\"amplitude\":{\"required\":[\"sigma_fact"
    "or\",\"additive_value\"],\"type\":\"object\",\"properties\":{\"additive_value\":{"
    "\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}},\"range\":{\"required"
    "\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object\",\"properties\":{\"add"
    "itive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}}}}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"filter\":{\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43"
    ",0.431,0.431,0.432],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88"
    ",7.85,7.83,7.8,7.78],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,"
    "15.7,15.8,15.9],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,"
    "-0.219,-0.221,-0.223,-0.225,-0.227]},\"result\":{\"amplitude_offset\":[1.9"
    ",1.9],\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067261,0.1054582,"
    "0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],\"timestamp"
    "\":[408.4441,411.4443],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816"
    ",0.4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487"
    ",0.4540681],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.09"
    "7782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"range_sigma\""
    ":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0."
    "01955329,0.02225589,0.02229977,0.01899122,0.02009433],\"angle\":[14.9,15"
    ".0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9]},\"settings\":{\"amplitu"
    "de\":{\"additive_value\":1.0,\"sigma_factor\":4},\"range\":{\"additive_value\":"
    "0.1,\"sigma_factor\":8}}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range\",\"slices\"],\"type\":\"object\",\"descriptio"
    "n\":\"Correction parameters for window glass echoes\",\"title\":\"Window "
    "Echo Correction\",\"properties\":{\"amplitude\":{\"required\":[\"minimum\",\"max"
    "imum\",\"entries\"],\"type\":\"object\",\"description\":\"Amplitude axis of "
    "correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of amplitude entries\",\"minimum\":1},\"minimum\":{\"type\":\"number\",\"descri"
    "ption\":\"Minimum amplitude in "
    "dB\",\"minimum\":0.0},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "amplitude in dB\",\"minimum\":0.0}}},\"range\":{\"required\":[\"minimum\",\"maxi"
    "mum\",\"entries\"],\"type\":\"object\",\"description\":\"Range axis of "
    "correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of range entries\",\"minimum\":1},\"minimum\":{\"type\":\"number\",\"descriptio"
    "n\":\"Minimum range in m\",\"minimum\":-2.0,\"maximum\":2.0},\"maximum\":{\"type"
    "\":\"number\",\"description\":\"Maximum range in m\",\"minimum\":-2.0,\"maximum\""
    ":2.0}}},\"slices\":{\"type\":\"array\",\"items\":{\"required\":[\"amplitude\",\"tab"
    "le\"],\"type\":\"object\",\"description\":\"Window echo correction parameter s"
    "lice\",\"properties\":{\"amplitude\":{\"type\":\"number\",\"description\":\"Window"
    " echo amplitude of slice in "
    "dB\"},\"table\":{\"type\":\"array\",\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"minItems\":1,\"items\":{\"type\":\"array\",\"description\":\"Table "
    "row (= amplitude axis)\",\"minItems\":1,\"items\":{\"maxItems\":3,\"type\":\"arr"
    "ay\",\"description\":\"Table column (= range "
    "axis)\",\"minItems\":3,\"items\":{\"type\":\"number\",\"description\":\"Table cell"
    " (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"}}}}}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"amplitude\":{\"entries\":128,\"minimum\":2,\"maximum\":20},\"range\":{\"entrie"
    "s\":128,\"minimum\":-1.5060822940732335,\"maximum\":1.5060822940732335},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
